==> primefaces-extensions-10.0.3.jar: META-INF/resources/primefaces-extensions/waypoint/waypoint.js <==
/*
 jQuery Waypoints - v2.0.5
Copyright (c) 2011-2014 Caleb Troughton
Licensed under the MIT license.
https://github.com/imakewebthings/jquery-waypoints/blob/master/licenses.txt
*/
var oldOffset=jQuery.fn.offset;jQuery.fn.offset=function(){var m=this[0],r={top:0,left:0};return m&&m.nodeType&&jQuery.contains((m.ownerDocument||document).documentElement,m)?oldOffset.apply(this,arguments):r};
(function(){var m=[].indexOf||function(c){for(var k=0,w=this.length;k<w;k++)if(k in this&&this[k]===c)return k;return-1},r=[].slice;(function(c,k){return"function"===typeof define&&define.amd?define("waypoints",["jquery"],function(w){return k(w,c)}):k(c.jQuery,c)})(window,function(c,k){var w=c(k);var z=0<=m.call(k,"ontouchstart");var u={horizontal:{},vertical:{}};var B=1;var x={};var C=1;var D=function(){function a(b){var d=this;this.$element=b;this.element=b[0];this.didScroll=this.didResize=!1;this.id=
"context"+B++;this.oldScroll={x:b.scrollLeft(),y:b.scrollTop()};this.waypoints={horizontal:{},vertical:{}};this.element["waypoints-context-id"]=this.id;x[this.id]=this;b.on("scroll.waypoints",function(){if(!d.didScroll&&!z)return d.didScroll=!0,k.setTimeout(function(){d.doScroll();return d.didScroll=!1},c.waypoints.settings.scrollThrottle)});b.on("resize.waypoints",function(){if(!d.didResize)return d.didResize=!0,k.setTimeout(function(){c.waypoints("refresh");return d.didResize=!1},c.waypoints.settings.resizeThrottle)})}
a.prototype.doScroll=function(){var b=this;var d={horizontal:{newScroll:this.$element.scrollLeft(),oldScroll:this.oldScroll.x,forward:"right",backward:"left"},vertical:{newScroll:this.$element.scrollTop(),oldScroll:this.oldScroll.y,forward:"down",backward:"up"}};!z||d.vertical.oldScroll&&d.vertical.newScroll||c.waypoints("refresh");c.each(d,function(e,f){var g;var h=[];var l=(g=f.newScroll>f.oldScroll)?f.forward:f.backward;c.each(b.waypoints[e],function(v,n){var t,y;if(f.oldScroll<(t=n.offset)&&t<=
f.newScroll||f.newScroll<(y=n.offset)&&y<=f.oldScroll)return h.push(n)});h.sort(function(v,n){return v.offset-n.offset});g||h.reverse();return c.each(h,function(v,n){if(n.options.continuous||v===h.length-1)return n.trigger([l])})});return this.oldScroll={x:d.horizontal.newScroll,y:d.vertical.newScroll}};a.prototype.refresh=function(){var b=this;var d=c.isWindow(this.element);var e=this.$element.offset();this.doScroll();e={horizontal:{contextOffset:d?0:e.left,contextScroll:d?0:this.oldScroll.x,contextDimension:this.$element.width(),
oldScroll:this.oldScroll.x,forward:"right",backward:"left",offsetProp:"left"},vertical:{contextOffset:d?0:e.top,contextScroll:d?0:this.oldScroll.y,contextDimension:d?c.waypoints("viewportHeight"):this.$element.height(),oldScroll:this.oldScroll.y,forward:"down",backward:"up",offsetProp:"top"}};return c.each(e,function(f,g){return c.each(b.waypoints[f],function(h,l){var v,n;h=l.options.offset;var t=l.offset;var y=c.isWindow(l.element)?0:l.$element.offset()[g.offsetProp];"function"===typeof h?h=h.apply(l.element):
"string"===typeof h&&(h=parseFloat(h),-1<l.options.offset.indexOf("%")&&(h=Math.ceil(g.contextDimension*h/100)));l.offset=y-g.contextOffset+g.contextScroll-h;if((!l.options.onlyOnScroll||null==t)&&l.enabled){if(null!==t&&t<(v=g.oldScroll)&&v<=l.offset)return l.trigger([g.backward]);if(null!==t&&t>(n=g.oldScroll)&&n>=l.offset||null===t&&g.oldScroll>=l.offset)return l.trigger([g.forward])}})})};a.prototype.checkEmpty=function(){if(c.isEmptyObject(this.waypoints.horizontal)&&c.isEmptyObject(this.waypoints.vertical))return this.$element.off("resize.waypoints scroll.waypoints"),
delete x[this.id]};return a}();var A=function(){function a(b,d,e){var f;"bottom-in-view"===e.offset&&(e.offset=function(){var g=c.waypoints("viewportHeight");c.isWindow(d.element)||(g=d.$element.height());return g-c(this).outerHeight()});this.$element=b;this.element=b[0];this.axis=e.horizontal?"horizontal":"vertical";this.callback=e.handler;this.context=d;this.enabled=e.enabled;this.id="waypoints"+C++;this.offset=null;this.options=e;d.waypoints[this.axis][this.id]=this;u[this.axis][this.id]=this;
b=null!=(f=this.element["waypoints-waypoint-ids"])?f:[];b.push(this.id);this.element["waypoints-waypoint-ids"]=b}a.prototype.trigger=function(b){if(this.enabled&&(null!=this.callback&&this.callback.apply(this.element,b),this.options.triggerOnce))return this.destroy()};a.prototype.disable=function(){return this.enabled=!1};a.prototype.enable=function(){this.context.refresh();return this.enabled=!0};a.prototype.destroy=function(){delete u[this.axis][this.id];delete this.context.waypoints[this.axis][this.id];
return this.context.checkEmpty()};a.getWaypointsByElement=function(b){b=b["waypoints-waypoint-ids"];if(!b)return[];var d=c.extend({},u.horizontal,u.vertical);return c.map(b,function(e){return d[e]})};return a}();var q={init:function(a,b){b=c.extend({},c.fn.waypoint.defaults,b);null==b.handler&&(b.handler=a);this.each(function(){var d;var e=c(this);var f=null!=(d=b.context)?d:c.fn.waypoint.defaults.context;c.isWindow(f)||(f=e.closest(f));f=c(f);(d=x[f[0]["waypoints-context-id"]])||(d=new D(f));return new A(e,
d,b)});c.waypoints("refresh");return this},disable:function(){return q._invoke.call(this,"disable")},enable:function(){return q._invoke.call(this,"enable")},destroy:function(){return q._invoke.call(this,"destroy")},prev:function(a,b){return q._traverse.call(this,a,b,function(d,e,f){if(0<e)return d.push(f[e-1])})},next:function(a,b){return q._traverse.call(this,a,b,function(d,e,f){if(e<f.length-1)return d.push(f[e+1])})},_traverse:function(a,b,d){null==a&&(a="vertical");null==b&&(b=k);var e=p.aggregate(b);
var f=[];this.each(function(){var g=c.inArray(this,e[a]);return d(f,g,e[a])});return this.pushStack(f)},_invoke:function(a){this.each(function(){var b=A.getWaypointsByElement(this);return c.each(b,function(d,e){e[a]();return!0})});return this}};c.fn.waypoint=function(){var a=arguments[0];var b=2<=arguments.length?r.call(arguments,1):[];return q[a]?q[a].apply(this,b):"function"===typeof a?q.init.apply(this,arguments):c.isPlainObject(a)?q.init.apply(this,[null,a]):a?c.on("error",function(){alert("The "+
a+" method does not exist in jQuery Waypoints.")}):c.on("error",function(){alert("jQuery Waypoints needs a callback function or handler option.")})};c.fn.waypoint.defaults={context:k,continuous:!0,enabled:!0,horizontal:!1,offset:0,triggerOnce:!1};var p={refresh:function(){return c.each(x,function(a,b){return b.refresh()})},viewportHeight:function(){var a;return null!=(a=k.innerHeight)?a:w.height()},aggregate:function(a){var b;var d=u;a&&(d=null!=(b=x[c(a)[0]["waypoints-context-id"]])?b.waypoints:
void 0);if(!d)return[];var e={horizontal:[],vertical:[]};c.each(e,function(f,g){c.each(d[f],function(h,l){return g.push(l)});g.sort(function(h,l){return h.offset-l.offset});e[f]=c.map(g,function(h){return h.element});return e[f]=c.uniqueSort(e[f])});return e},above:function(a){null==a&&(a=k);return p._filter(a,"vertical",function(b,d){return d.offset<=b.oldScroll.y})},below:function(a){null==a&&(a=k);return p._filter(a,"vertical",function(b,d){return d.offset>b.oldScroll.y})},left:function(a){null==
a&&(a=k);return p._filter(a,"horizontal",function(b,d){return d.offset<=b.oldScroll.x})},right:function(a){null==a&&(a=k);return p._filter(a,"horizontal",function(b,d){return d.offset>b.oldScroll.x})},enable:function(){return p._invoke("enable")},disable:function(){return p._invoke("disable")},destroy:function(){return p._invoke("destroy")},extendFn:function(a,b){return q[a]=b},_invoke:function(a){var b=c.extend({},u.vertical,u.horizontal);return c.each(b,function(d,e){e[a]();return!0})},_filter:function(a,
b,d){var e=x[c(a)[0]["waypoints-context-id"]];if(!e)return[];var f=[];c.each(e.waypoints[b],function(g,h){if(d(e,h))return f.push(h)});f.sort(function(g,h){return g.offset-h.offset});return c.map(f,function(g){return g.element})}};c.waypoints=function(){var a=arguments[0];var b=2<=arguments.length?r.call(arguments,1):[];return p[a]?p[a].apply(null,b):p.aggregate.call(null,a)};c.waypoints.settings={resizeThrottle:100,scrollThrottle:30};return w.on("load.waypoints",function(){return c.waypoints("refresh")})})}).call(this);
PrimeFaces.widget.ExtWaypoint=PrimeFaces.widget.BaseWidget.extend({init:function(m){this._super(m);this.cfg=m;this.id=m.id;this.target=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.target);delete this.cfg.target;this.cfg.context&&(this.cfg.context=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.context));this.destroy().create()},destroy:function(){this.target.waypoint("destroy");return this},disable:function(){this.target.waypoint("disable");
return this},enable:function(){this.target.waypoint("enable");return this},create:function(){var m=this;this.target.waypoint(function(r){m.reached(r,this)},this.cfg)},refresh:function(){$.waypoints("refresh")},reached:function(m,r){this.hasBehavior("reached")&&(m={params:[{name:this.id+"_direction",value:m},{name:this.id+"_waypointId",value:$(r).attr("id")}],direction:m,waypoint:r},this.callBehavior("reached",m))}});

==> primefaces-extensions-14.0.10.jar: META-INF/resources/primefaces-extensions/waypoint/waypoint.js <==
/*
 jQuery Waypoints - v2.0.5
Copyright (c) 2011-2014 Caleb Troughton
Licensed under the MIT license.
https://github.com/imakewebthings/jquery-waypoints/blob/master/licenses.txt
*/
var oldOffset=jQuery.fn.offset;jQuery.fn.offset=function(){var m=this[0],r={top:0,left:0};return m&&m.nodeType&&jQuery.contains((m.ownerDocument||document).documentElement,m)?oldOffset.apply(this,arguments):r};
(function(){var m=[].indexOf||function(c){for(var k=0,w=this.length;k<w;k++)if(k in this&&this[k]===c)return k;return-1},r=[].slice;(function(c,k){return"function"===typeof define&&define.amd?define("waypoints",["jquery"],function(w){return k(w,c)}):k(c.jQuery,c)})(window,function(c,k){var w=c(k);var z=0<=m.call(k,"ontouchstart");var u={horizontal:{},vertical:{}};var B=1;var x={};var C=1;var D=function(){function a(b){var d=this;this.$element=b;this.element=b[0];this.didScroll=this.didResize=!1;this.id=
"context"+B++;this.oldScroll={x:b.scrollLeft(),y:b.scrollTop()};this.waypoints={horizontal:{},vertical:{}};this.element["waypoints-context-id"]=this.id;x[this.id]=this;b.on("scroll.waypoints",function(){if(!d.didScroll&&!z)return d.didScroll=!0,k.setTimeout(function(){d.doScroll();return d.didScroll=!1},c.waypoints.settings.scrollThrottle)});b.on("resize.waypoints",function(){if(!d.didResize)return d.didResize=!0,k.setTimeout(function(){c.waypoints("refresh");return d.didResize=!1},c.waypoints.settings.resizeThrottle)})}
a.prototype.doScroll=function(){var b=this;var d={horizontal:{newScroll:this.$element.scrollLeft(),oldScroll:this.oldScroll.x,forward:"right",backward:"left"},vertical:{newScroll:this.$element.scrollTop(),oldScroll:this.oldScroll.y,forward:"down",backward:"up"}};!z||d.vertical.oldScroll&&d.vertical.newScroll||c.waypoints("refresh");c.each(d,function(e,f){var g;var h=[];var l=(g=f.newScroll>f.oldScroll)?f.forward:f.backward;c.each(b.waypoints[e],function(v,n){var t,y;if(f.oldScroll<(t=n.offset)&&t<=
f.newScroll||f.newScroll<(y=n.offset)&&y<=f.oldScroll)return h.push(n)});h.sort(function(v,n){return v.offset-n.offset});g||h.reverse();return c.each(h,function(v,n){if(n.options.continuous||v===h.length-1)return n.trigger([l])})});return this.oldScroll={x:d.horizontal.newScroll,y:d.vertical.newScroll}};a.prototype.refresh=function(){var b=this;var d=c.isWindow(this.element);var e=this.$element.offset();this.doScroll();e={horizontal:{contextOffset:d?0:e.left,contextScroll:d?0:this.oldScroll.x,contextDimension:this.$element.width(),
oldScroll:this.oldScroll.x,forward:"right",backward:"left",offsetProp:"left"},vertical:{contextOffset:d?0:e.top,contextScroll:d?0:this.oldScroll.y,contextDimension:d?c.waypoints("viewportHeight"):this.$element.height(),oldScroll:this.oldScroll.y,forward:"down",backward:"up",offsetProp:"top"}};return c.each(e,function(f,g){return c.each(b.waypoints[f],function(h,l){var v,n;h=l.options.offset;var t=l.offset;var y=c.isWindow(l.element)?0:l.$element.offset()[g.offsetProp];"function"===typeof h?h=h.apply(l.element):
"string"===typeof h&&(h=parseFloat(h),-1<l.options.offset.indexOf("%")&&(h=Math.ceil(g.contextDimension*h/100)));l.offset=y-g.contextOffset+g.contextScroll-h;if((!l.options.onlyOnScroll||null==t)&&l.enabled){if(null!==t&&t<(v=g.oldScroll)&&v<=l.offset)return l.trigger([g.backward]);if(null!==t&&t>(n=g.oldScroll)&&n>=l.offset||null===t&&g.oldScroll>=l.offset)return l.trigger([g.forward])}})})};a.prototype.checkEmpty=function(){if(c.isEmptyObject(this.waypoints.horizontal)&&c.isEmptyObject(this.waypoints.vertical))return this.$element.off("resize.waypoints scroll.waypoints"),
delete x[this.id]};return a}();var A=function(){function a(b,d,e){var f;"bottom-in-view"===e.offset&&(e.offset=function(){var g=c.waypoints("viewportHeight");c.isWindow(d.element)||(g=d.$element.height());return g-c(this).outerHeight()});this.$element=b;this.element=b[0];this.axis=e.horizontal?"horizontal":"vertical";this.callback=e.handler;this.context=d;this.enabled=e.enabled;this.id="waypoints"+C++;this.offset=null;this.options=e;d.waypoints[this.axis][this.id]=this;u[this.axis][this.id]=this;
b=null!=(f=this.element["waypoints-waypoint-ids"])?f:[];b.push(this.id);this.element["waypoints-waypoint-ids"]=b}a.prototype.trigger=function(b){if(this.enabled&&(null!=this.callback&&this.callback.apply(this.element,b),this.options.triggerOnce))return this.destroy()};a.prototype.disable=function(){return this.enabled=!1};a.prototype.enable=function(){this.context.refresh();return this.enabled=!0};a.prototype.destroy=function(){delete u[this.axis][this.id];delete this.context.waypoints[this.axis][this.id];
return this.context.checkEmpty()};a.getWaypointsByElement=function(b){b=b["waypoints-waypoint-ids"];if(!b)return[];var d=c.extend({},u.horizontal,u.vertical);return c.map(b,function(e){return d[e]})};return a}();var q={init:function(a,b){b=c.extend({},c.fn.waypoint.defaults,b);null==b.handler&&(b.handler=a);this.each(function(){var d;var e=c(this);var f=null!=(d=b.context)?d:c.fn.waypoint.defaults.context;c.isWindow(f)||(f=e.closest(f));f=c(f);(d=x[f[0]["waypoints-context-id"]])||(d=new D(f));return new A(e,
d,b)});c.waypoints("refresh");return this},disable:function(){return q._invoke.call(this,"disable")},enable:function(){return q._invoke.call(this,"enable")},destroy:function(){return q._invoke.call(this,"destroy")},prev:function(a,b){return q._traverse.call(this,a,b,function(d,e,f){if(0<e)return d.push(f[e-1])})},next:function(a,b){return q._traverse.call(this,a,b,function(d,e,f){if(e<f.length-1)return d.push(f[e+1])})},_traverse:function(a,b,d){null==a&&(a="vertical");null==b&&(b=k);var e=p.aggregate(b);
var f=[];this.each(function(){var g=c.inArray(this,e[a]);return d(f,g,e[a])});return this.pushStack(f)},_invoke:function(a){this.each(function(){var b=A.getWaypointsByElement(this);return c.each(b,function(d,e){e[a]();return!0})});return this}};c.fn.waypoint=function(){var a=arguments[0];var b=2<=arguments.length?r.call(arguments,1):[];return q[a]?q[a].apply(this,b):"function"===typeof a?q.init.apply(this,arguments):c.isPlainObject(a)?q.init.apply(this,[null,a]):a?c.on("error",function(){alert("The "+
a+" method does not exist in jQuery Waypoints.")}):c.on("error",function(){alert("jQuery Waypoints needs a callback function or handler option.")})};c.fn.waypoint.defaults={context:k,continuous:!0,enabled:!0,horizontal:!1,offset:0,triggerOnce:!1};var p={refresh:function(){return c.each(x,function(a,b){return b.refresh()})},viewportHeight:function(){var a;return null!=(a=k.innerHeight)?a:w.height()},aggregate:function(a){var b;var d=u;a&&(d=null!=(b=x[c(a)[0]["waypoints-context-id"]])?b.waypoints:
void 0);if(!d)return[];var e={horizontal:[],vertical:[]};c.each(e,function(f,g){c.each(d[f],function(h,l){return g.push(l)});g.sort(function(h,l){return h.offset-l.offset});e[f]=c.map(g,function(h){return h.element});return e[f]=c.uniqueSort(e[f])});return e},above:function(a){null==a&&(a=k);return p._filter(a,"vertical",function(b,d){return d.offset<=b.oldScroll.y})},below:function(a){null==a&&(a=k);return p._filter(a,"vertical",function(b,d){return d.offset>b.oldScroll.y})},left:function(a){null==
a&&(a=k);return p._filter(a,"horizontal",function(b,d){return d.offset<=b.oldScroll.x})},right:function(a){null==a&&(a=k);return p._filter(a,"horizontal",function(b,d){return d.offset>b.oldScroll.x})},enable:function(){return p._invoke("enable")},disable:function(){return p._invoke("disable")},destroy:function(){return p._invoke("destroy")},extendFn:function(a,b){return q[a]=b},_invoke:function(a){var b=c.extend({},u.vertical,u.horizontal);return c.each(b,function(d,e){e[a]();return!0})},_filter:function(a,
b,d){var e=x[c(a)[0]["waypoints-context-id"]];if(!e)return[];var f=[];c.each(e.waypoints[b],function(g,h){if(d(e,h))return f.push(h)});f.sort(function(g,h){return g.offset-h.offset});return c.map(f,function(g){return g.element})}};c.waypoints=function(){var a=arguments[0];var b=2<=arguments.length?r.call(arguments,1):[];return p[a]?p[a].apply(null,b):p.aggregate.call(null,a)};c.waypoints.settings={resizeThrottle:100,scrollThrottle:30};return w.on("load.waypoints",function(){return c.waypoints("refresh")})})}).call(this);
PrimeFaces.widget.ExtWaypoint=PrimeFaces.widget.BaseWidget.extend({init:function(m){this._super(m);this.cfg=m;this.id=m.id;this.target=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.jq,this.cfg.target);delete this.cfg.target;this.cfg.context&&(this.cfg.context=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.jq,this.cfg.context));this.destroy().create()},destroy:function(){this.target.waypoint("destroy");return this},disable:function(){this.target.waypoint("disable");
return this},enable:function(){this.target.waypoint("enable");return this},create:function(){var m=this;this.target.waypoint(function(r){m.reached(r,this)},this.cfg)},refresh:function(){$.waypoints("refresh")},reached:function(m,r){this.hasBehavior("reached")&&(m={params:[{name:this.id+"_direction",value:m},{name:this.id+"_waypointId",value:$(r).attr("id")}],direction:m,waypoint:r},this.callBehavior("reached",m))}});
